Affected by GO-2023-1939
and 6 other vulnerabilities
GO-2023-1939: Mattermost Server Sensitive Data Exposure in github.com/mattermost/mattermost
GO-2025-4122: Mattermost Incorrect Authorization vulnerability in github.com/mattermost/mattermost
GO-2025-4126: Mattermost fails to properly restrict access to archived channel search API in github.com/mattermost/mattermost
GO-2025-4172: Mattermost fails to validate user permissions when deleting comments in Boards in github.com/mattermost/mattermost
GO-2025-4172: Mattermost fails to validate user permissions when deleting comments in Boards in github.com/mattermost/mattermost
GO-2025-4172: Mattermost fails to validate user permissions when deleting comments in Boards in github.com/mattermost/mattermost
GO-2025-4172: Mattermost fails to validate user permissions when deleting comments in Boards in github.com/mattermost/mattermost
package
Version:
v5.11.1+incompatible
Opens a new window with list of versions in this module.
Published: Jun 11, 2019
License: AGPL-3.0, Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Timezones struct {
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.